@@ -1,6 +1,6 @@
 #Copyright (C) 2008 Codethink Ltd
 
-#his program is free software; you can redistribute it and/or modify
+#This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
 #the Free Software Foundation; either version 2 of the License, or
 #(at your option) any later version.
@@ -80,7 +80,7 @@ class PasyTestFunc(PasyTestStep):
 		try:
 			self._func(self)
 		except Exception as e:
-			self.fail(e.message)
+			self.fail(str(e))
 			traceback.print_exc()
 		self.win()
 
